@@ -137,6 +137,14 @@ def findThreshold(model_name, distance_metric):
 		elif distance_metric == 'euclidean_l2':
 			threshold = 0.17
 	
+	elif model_name == 'Dlib':
+		if distance_metric == 'cosine':
+			threshold = 0.07
+		elif distance_metric == 'euclidean':
+			threshold = 0.60
+		elif distance_metric == 'euclidean_l2':
+			threshold = 0.60
+	
 	return threshold
 
 def get_opencv_path():
@@ -197,7 +205,12 @@ def detectFace(img, target_size=(224, 224), grayscale = False, enforce_detection
 	
 	#--------------------------------
 	
-	faces = face_detector.detectMultiScale(img, 1.3, 5)
+	faces = []
+	
+	try:
+		faces = face_detector.detectMultiScale(img, 1.3, 5)
+	except:
+		pass
 	
 	#print("found faces in ",image_path," is ",len(faces))
 	
@@ -265,24 +278,26 @@ def detectFace(img, target_size=(224, 224), grayscale = False, enforce_detection
 			#-----------------------
 			#apply cosine rule
 			
-			cos_a = (b*b + c*c - a*a)/(2*b*c)
-			angle = np.arccos(cos_a) #angle in radian
-			angle = (angle * 180) / math.pi #radian to degree
+			if b != 0 and c != 0: #this multiplication causes division by zero in cos_a calculation
 			
-			#-----------------------
-			#rotate base image
-			
-			if direction == -1:
-				angle = 90 - angle
-			
-			img = Image.fromarray(img_raw)
-			img = np.array(img.rotate(direction * angle))
-			
-			#you recover the base image and face detection disappeared. apply again.
-			faces = face_detector.detectMultiScale(img, 1.3, 5)
-			if len(faces) > 0:
-				x,y,w,h = faces[0]
-				detected_face = img[int(y):int(y+h), int(x):int(x+w)]
+				cos_a = (b*b + c*c - a*a)/(2*b*c)
+				angle = np.arccos(cos_a) #angle in radian
+				angle = (angle * 180) / math.pi #radian to degree
+				
+				#-----------------------
+				#rotate base image
+				
+				if direction == -1:
+					angle = 90 - angle
+				
+				img = Image.fromarray(img_raw)
+				img = np.array(img.rotate(direction * angle))
+				
+				#you recover the base image and face detection disappeared. apply again.
+				faces = face_detector.detectMultiScale(img, 1.3, 5)
+				if len(faces) > 0:
+					x,y,w,h = faces[0]
+					detected_face = img[int(y):int(y+h), int(x):int(x+w)]
 			
 			#-----------------------
 		
